==> gnome-do-plugins_0.6.0.1+dfsg.orig.tar.gz: gnome-do-plugins-0.6.0.1/Pastebin/src/PastebinAction.cs <==
//  PastebinAction.cs
//
//  GNOME Do is the legal property of its developers, whose names are too
//  numerous to list here.  Please refer to the COPYRIGHT file distributed with
//  this source distribution.
//
//  This program is free software: you can redistribute it and/or modify it
//  under the terms of the GNU General Public License as published by the Free
//  Software Foundation, either version 3 of the License, or (at your option)
//  any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT
//  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
//  more details.
//
//  You should have received a copy of the GNU General Public License along with
//  this program.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.IO;
using System.Net;
using System.Text;
using System.Collections.Generic;
using System.Text.RegularExpressions;

using Do.Addins;
using Do.Universe;

using Mono.Unix;

namespace Pastebin
{
	public class PastebinAction : AbstractAction, IConfigurable
	{
		public override string Name
		{
			get { return Catalog.GetString ("Send to Pastebin"); }
		}
		
		public override string Description
		{
			get { return Catalog.GetString ("Sends the text to Pastebin."); }
		}
		
		public override string Icon
		{
			get { return "gtk-paste"; }
		}
		
		public override Type[] SupportedItemTypes
		{
			get 
			{
				return new Type[] {
					typeof (ITextItem),
					typeof (IFileItem)
				};
			}
		}
			
		public override bool ModifierItemsOptional
		{
			get { return true; }
		}
		
		public override Type[] SupportedModifierItemTypes
		{
			get 
			{
				return new Type[] {
					typeof (ITextSyntaxItem)
				};
			}
		}
		
		public override bool SupportsItem (IItem item)
		{
			if (item is ITextItem) return true;
			if (item is FileItem) {	
				if ((item as FileItem).MimeType.StartsWith ("text/") || 
				(item as FileItem).MimeType.EndsWith ("/x-perl"))
				return true;
			}
			return false;
		}
			
		public override IItem[] DynamicModifierItemsForItem (IItem item)
		{
			IPastebinProvider pastebinProvider = PastebinProviderFactory.GetProviderFromPreferences ();

			List<IItem> items = new List<IItem> ();

			foreach (IItem languageItem in pastebinProvider.SupportedLanguages) {
				items.Add (languageItem);
			}
										
			return items.ToArray ();
		}
				
		public override IItem[] Perform (IItem[] items, IItem[] modifierItems)
		{		
			string text = string.Empty;
			ITextItem titem = null;
			
			foreach (IItem item in items) {
				if (item is IFileItem)
					titem = new TextItem (File.ReadAllText (
						(item as IFileItem).Path));
				else
					titem = new TextItem ((item as ITextItem).Text);
				text += titem.Text;
			}
			
			IPastebinProvider pastebinProvider = null;
					
			if (modifierItems.Length > 0) {
				pastebinProvider = PastebinProviderFactory.GetProviderFromPreferences (text, (modifierItems[0] as ITextSyntaxItem).Syntax);
			}
			else {
				pastebinProvider = PastebinProviderFactory.GetProviderFromPreferences (text);		
			}
					
			string url = Pastebin.PostUsing (pastebinProvider);	
					
			return new IItem[] { new TextItem (url) };
		}
				
		public Gtk.Bin GetConfiguration ()
		{
			return new PastebinConfig();
		}				
	}
}

==> gnome-do-plugins_0.8.1.3+dfsg.orig.tar.gz: gnome-do-plugins-0.8.1.3/Pastebin/src/PastebinAction.cs <==
//  PastebinAction.cs
//
//  GNOME Do is the legal property of its developers, whose names are too
//  numerous to list here.  Please refer to the COPYRIGHT file distributed with
//  this source distribution.
//
//  This program is free software: you can redistribute it and/or modify it
//  under the terms of the GNU General Public License as published by the Free
//  Software Foundation, either version 3 of the License, or (at your option)
//  any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT
//  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
//  more details.
//
//  You should have received a copy of the GNU General Public License along with
//  this program.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Text;
using System.Text.RegularExpressions;

using Do.Platform;
using Do.Platform.Linux;
using Do.Universe;
using Do.Universe.Common;

using Mono.Unix;

namespace Pastebin
{
	public class PastebinAction : Act, IConfigurable
	{
		public override string Name {
			get { return Catalog.GetString ("Send to Pastebin"); }
		}
		
		public override string Description {
			get { return Catalog.GetString ("Sends the text to Pastebin."); }
		}
		
		public override string Icon {
			get { return "gtk-paste"; }
		}
		
		public override IEnumerable<Type> SupportedItemTypes {
			get {
				yield return typeof (ITextItem);
				yield return typeof (IFileItem);
			}
		}
			
		public override bool ModifierItemsOptional  {
			get { return true; }
		}
		
		public override IEnumerable<Type> SupportedModifierItemTypes
		{
			get { yield return typeof (ITextSyntaxItem); }
		}
		
		public override bool SupportsItem (Item item)
		{
			if (item is ITextItem) return true;
			if (item is IFileItem) {
				IFileItem file = item as IFileItem;
				if (Directory.Exists (file.Path)) return false;
				long kbSize = new FileInfo (file.Path).Length / 1024;
				return kbSize < 100;
			}
			return false;
		}
			
		public override IEnumerable<Item> DynamicModifierItemsForItem (Item item)
		{
			IPastebinProvider pastebinProvider = PastebinProviderFactory.GetProviderFromPreferences ();
			return pastebinProvider.SupportedLanguages.OfType<Item> ();
		}
				
		public override IEnumerable<Item> Perform (IEnumerable<Item> items, IEnumerable<Item> modifierItems)
		{		
			string text = string.Empty;
			ITextItem titem = null;
			
			foreach (Item item in items) {
				if (item is IFileItem)
					titem = new TextItem (File.ReadAllText (
						(item as IFileItem).Path));
				else
					titem = new TextItem ((item as ITextItem).Text);
				text += titem.Text;
			}
			
			IPastebinProvider pastebinProvider = null;
					
			if (modifierItems.Any ()) {
				pastebinProvider = PastebinProviderFactory.GetProviderFromPreferences (text, (modifierItems.First () as ITextSyntaxItem).Syntax);
			}
			else {
				pastebinProvider = PastebinProviderFactory.GetProviderFromPreferences (text);		
			}
					
			string url = Pastebin.PostUsing (pastebinProvider);	
					
			yield return new TextItem (url);
		}
				
		public Gtk.Bin GetConfiguration ()
		{
			return new PastebinConfig();
		}				
	}
}
